.. currentmodule:: xweights

#############
API reference
#############

This page provides an auto-generated summary of the xweights API.

Top-level functions
===================

.. autosummary::
   :toctree: generated/

   compute_weighted_means		
   compute_weighted_means_ds

Read input data
===============

.. autosummary::
   :toctree: generated/

   Input
   
CORDEX domains
==============

.. autosummary::
   :toctree: generated/

   get_domain
   which_domains

Pre-defined regions
===================

.. autosummary::
   :toctree: generated/
	     
   get_region
   which_regions
   which_subregions

xesmf's spatial averager
========================

.. autosummary::
   :toctree: generated/

   spatial_averager


